@@ -4,9 +4,9 @@ from .chooser import choose
 from .selector import selector
 from .actions import actions
 from .list import List, Scrollbar, ColumnList, Header
-from .core import BlockingInput, NonblockingInput
+from .core import BlockingInput, NonblockingInput, Echo, Cursor
 
-__version__ = '0.0.6'
+__version__ = '0.0.7'
 __all__ = (
         'Menu',
         'Text',
@@ -19,4 +19,6 @@ __all__ = (
         'actions',
         'BlockingInput',
         'NonblockingInput',
+        'Echo',
+        'Cursor',
         )
