@@ -20,6 +20,25 @@ class NonblockingInput:
         curses.nocbreak()
 
 
+class Echo:
+    def __enter__(self):
+        curses.echo()
+
+    def __exit__(self, *args):
+        curses.noecho()
+
+
+class Cursor:
+    def __init__(self, visibility=2):
+        self.visibility = visibility
+
+    def __enter__(self):
+        curses.curs_set(self.visibility)
+
+    def __exit__(self, *args):
+        curses.curs_set(0)
+
+
 class Window:
     def __init__(self, row, col, height, width):
         self.row = row
