@@ -1,6 +1,6 @@
 import curses
 
-from .core import Window, Cbreak
+from .core import Window, BlockingInput
 
 
 class Menu(Window):
@@ -19,7 +19,7 @@ class Menu(Window):
         self.win.refresh()
 
     def get_selection(self):
-        with Cbreak():
+        with BlockingInput():
             selected = None
             focus = 0
             while selected is None:
